aboutsummaryrefslogtreecommitdiff
path: root/test/functional/legacy/edit_spec.lua
diff options
context:
space:
mode:
Diffstat (limited to 'test/functional/legacy/edit_spec.lua')
-rw-r--r--test/functional/legacy/edit_spec.lua10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/functional/legacy/edit_spec.lua b/test/functional/legacy/edit_spec.lua
index c79213656f..0def49b85d 100644
--- a/test/functional/legacy/edit_spec.lua
+++ b/test/functional/legacy/edit_spec.lua
@@ -56,20 +56,20 @@ describe('edit', function()
{1:~ }|*4
{5:-- INSERT --} |
]])
- feed('={}')
+ feed('=0z')
screen:expect([[
{18:"} |
{1:~ }|*4
- ={16:{}}^ |
+ ={26:0}{9:z}^ |
]])
- -- trying to insert a dictionary produces an error
+ -- trying to insert a blob produces an error
feed('<CR>')
screen:expect([[
{18:"} |
{1:~ }|
{3: }|
- ={16:{}} |
- {9:E731: Using a Dictionary as a String} |
+ ={26:0}{9:z} |
+ {9:E976: Using a Blob as a String} |
{6:Press ENTER or type command to continue}^ |
]])